"use strict";
const postcss = require("postcss");
const filterSelector = require("./filter-selector");
module.exports = function postcssSelectorExtract(filters = []) {
    return postcss.plugin(`postcss-extract-selectors`, () => (nodes) => {
        // We have to force `any` type, because postcss type
        // definitions seem to be outdated.
        nodes.walkRules((rule) => {
            const ruleSelectors = rule.selector
                .split(`,`)
                .map((ruleSelector) => ruleSelector.replace(/(\r\n|\n|\r)/gm, ``).trim())
                .map((ruleSelector) => filterSelector({
                ruleSelector,
                ruleParentSelectors: rule.parent.selector ? rule.parent.selector.split(`,`) : [],
                filters,
            }))
                .filter((ruleSelector) => ruleSelector.length);
            if (ruleSelectors.length) {
                rule.selector = ruleSelectors.join(`,`);
            }
            else {
                rule.remove();
            }
        });
        // Remove empty @ rules.
        nodes.walkAtRules((rule) => {
            if (rule.nodes && !rule.nodes.length) {
                rule.remove();
            }
        });
    });
};
//# sourceMappingURL=postcss-selector-extract.js.map